@@ -171,12 +171,12 @@ class TopLevelCommand(object):
                                   in the client certificate (for example if your docker host
                                   is an IP address)
       --project-directory PATH    Specify an alternate working directory
-                                  (default: the path of the compose file)
+                                  (default: the path of the Compose file)
 
     Commands:
       build              Build or rebuild services
       bundle             Generate a Docker bundle from the Compose file
-      config             Validate and view the compose file
+      config             Validate and view the Compose file
       create             Create services
       down               Stop and remove containers, networks, images, and volumes
       events             Receive real time events from containers
@@ -273,7 +273,7 @@ class TopLevelCommand(object):
 
     def config(self, config_options, options):
         """
-        Validate and view the compose file.
+        Validate and view the Compose file.
 
         Usage: config [options]
 
@@ -391,7 +391,7 @@ class TopLevelCommand(object):
         Options:
             -d                Detached mode: Run command in the background.
             --privileged      Give extended privileges to the process.
-            --user USER       Run the command as this user.
+            -u, --user USER   Run the command as this user.
             -T                Disable pseudo-tty allocation. By default `docker-compose exec`
                               allocates a TTY.
             --index=index     index of the container if there are multiple
@@ -627,18 +627,20 @@ class TopLevelCommand(object):
 
     def pull(self, options):
         """
-        Pulls images for services.
+        Pulls images for services defined in a Compose file, but does not start the containers.
 
         Usage: pull [options] [SERVICE...]
 
         Options:
             --ignore-pull-failures  Pull what it can and ignores images with pull failures.
             --parallel              Pull multiple images in parallel.
+            --quiet                 Pull without printing progress information
         """
         self.project.pull(
             service_names=options['SERVICE'],
             ignore_pull_failures=options.get('--ignore-pull-failures'),
-            parallel_pull=options.get('--parallel')
+            parallel_pull=options.get('--parallel'),
+            silent=options.get('--quiet'),
         )
 
     def push(self, options):
@@ -680,13 +682,7 @@ class TopLevelCommand(object):
         one_off = OneOffFilter.include
 
         if options.get('--stop'):
-            running_containers = self.project.containers(
-                service_names=options['SERVICE'], stopped=False, one_off=one_off
-            )
-            self.project.stop(
-                service_names=running_containers,
-                one_off=one_off
-            )
+            self.project.stop(service_names=options['SERVICE'], one_off=one_off)
 
         all_containers = self.project.containers(
             service_names=options['SERVICE'], stopped=True, one_off=one_off
@@ -764,6 +760,9 @@ class TopLevelCommand(object):
 
             $ docker-compose scale web=2 worker=3
 
+        This command is deprecated. Use the up command with the `--scale` flag
+        instead.
+
         Usage: scale [options] [SERVICE=NUM...]
 
         Options:
@@ -777,6 +776,11 @@ class TopLevelCommand(object):
                 'The scale command is incompatible with the v2.2 format. '
                 'Use the up command with the --scale flag instead.'
             )
+        else:
+            log.warn(
+                'The scale command is deprecated. '
+                'Use the up command with the --scale flag instead.'
+            )
 
         for service_name, num in parse_scale_args(options['SERVICE=NUM']).items():
             self.project.get_service(service_name).scale(num, timeout=timeout)
@@ -1130,7 +1134,9 @@ def run_one_off_container(container_options, project, service, options):
             project.up(
                 service_names=deps,
                 start_deps=True,
-                strategy=ConvergenceStrategy.never)
+                strategy=ConvergenceStrategy.never,
+                rescale=False
+            )
 
     project.initialize()
 
