@@ -7,8 +7,7 @@ import yaml
 from compose.config import types
 from compose.const import COMPOSEFILE_V1 as V1
 from compose.const import COMPOSEFILE_V2_1 as V2_1
-from compose.const import COMPOSEFILE_V2_2 as V2_2
-from compose.const import COMPOSEFILE_V3_1 as V3_1
+from compose.const import COMPOSEFILE_V3_0 as V3_0
 from compose.const import COMPOSEFILE_V3_2 as V3_2
 
 
@@ -21,14 +20,27 @@ def serialize_dict_type(dumper, data):
     return dumper.represent_dict(data.repr())
 
 
+def serialize_string(dumper, data):
+    """ Ensure boolean-like strings are quoted in the output """
+    representer = dumper.represent_str if six.PY3 else dumper.represent_unicode
+    if data.lower() in ('y', 'n', 'yes', 'no', 'on', 'off', 'true', 'false'):
+        # Empirically only y/n appears to be an issue, but this might change
+        # depending on which PyYaml version is being used. Err on safe side.
+        return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='"')
+    return representer(data)
+
+
 yaml.SafeDumper.add_representer(types.VolumeFromSpec, serialize_config_type)
 yaml.SafeDumper.add_representer(types.VolumeSpec, serialize_config_type)
 yaml.SafeDumper.add_representer(types.ServiceSecret, serialize_dict_type)
+yaml.SafeDumper.add_representer(types.ServiceConfig, serialize_dict_type)
 yaml.SafeDumper.add_representer(types.ServicePort, serialize_dict_type)
+yaml.SafeDumper.add_representer(str, serialize_string)
+yaml.SafeDumper.add_representer(six.text_type, serialize_string)
 
 
 def denormalize_config(config, image_digests=None):
-    result = {'version': V2_1 if config.version == V1 else config.version}
+    result = {'version': str(V2_1) if config.version == V1 else str(config.version)}
     denormalized_services = [
         denormalize_service_dict(
             service_dict,
@@ -40,21 +52,15 @@ def denormalize_config(config, image_digests=None):
         service_dict.pop('name'): service_dict
         for service_dict in denormalized_services
     }
-    result['networks'] = config.networks.copy()
-    for net_name, net_conf in result['networks'].items():
-        if 'external_name' in net_conf:
-            del net_conf['external_name']
+    for key in ('networks', 'volumes', 'secrets', 'configs'):
+        config_dict = getattr(config, key)
+        if not config_dict:
+            continue
+        result[key] = config_dict.copy()
+        for name, conf in result[key].items():
+            if 'external_name' in conf:
+                del conf['external_name']
 
-    result['volumes'] = config.volumes.copy()
-    for vol_name, vol_conf in result['volumes'].items():
-        if 'external_name' in vol_conf:
-            del vol_conf['external_name']
-
-    if config.version in (V3_1, V3_2):
-        result['secrets'] = config.secrets.copy()
-        for secret_name, secret_conf in result['secrets'].items():
-            if 'external_name' in secret_conf:
-                del secret_conf['external_name']
     return result
 
 
@@ -63,7 +69,8 @@ def serialize_config(config, image_digests=None):
         denormalize_config(config, image_digests),
         default_flow_style=False,
         indent=2,
-        width=80)
+        width=80
+    )
 
 
 def serialize_ns_time_value(value):
@@ -99,7 +106,7 @@ def denormalize_service_dict(service_dict, version, image_digest=None):
     if version == V1 and 'network_mode' not in service_dict:
         service_dict['network_mode'] = 'bridge'
 
-    if 'depends_on' in service_dict and version not in (V2_1, V2_2):
+    if 'depends_on' in service_dict and (version < V2_1 or version >= V3_0):
         service_dict['depends_on'] = sorted([
             svc for svc in service_dict['depends_on'].keys()
         ])
@@ -114,7 +121,7 @@ def denormalize_service_dict(service_dict, version, image_digest=None):
                 service_dict['healthcheck']['timeout']
             )
 
-    if 'ports' in service_dict and version not in (V3_2,):
+    if 'ports' in service_dict and version < V3_2:
         service_dict['ports'] = [
             p.legacy_repr() if isinstance(p, types.ServicePort) else p
             for p in service_dict['ports']
